@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced;
 
 use Moo;
 
-our $VERSION = '0.000014';
+our $VERSION = '0.000015';
 
 use feature qw( say state );
 
@@ -220,16 +220,11 @@ sub get_response_from_silent_post {
 sub inquiry_transaction {
     my $self = shift;
 
-    state $check = compile(NonEmptyStr);
-    my ($pnref) = $check->(@_);
+    state $check = compile(HashRef);
+    my ($args) = $check->(@_);
+    $args->{TRXTYPE} = 'I';
 
-    return $self->post(
-        {
-            ORIGID  => $pnref,
-            TENDER  => 'C',
-            TRXTYPE => 'I',
-        }
-    );
+    return $self->post($args);
 }
 
 sub post {
@@ -426,7 +421,7 @@ WebService::PayPal::PaymentsAdvanced - A simple wrapper around the PayPal Paymen
 
 =head1 VERSION
 
-version 0.000014
+version 0.000015
 
 =head1 SYNOPSIS
 
@@ -732,11 +727,19 @@ argument.
     );
     say $response->message;
 
-=head3 inquiry_transaction( $ORIGID )
+=head3 inquiry_transaction( $HashRef )
 
 Performs a transaction inquiry on a previously submitted transaction.  Requires
 the ID of the original transaction.  Returns a response object.
 
+    use WebService::PayPal::PaymentsAdvanced;
+    my $payments = WebService::PayPal::PaymentsAdvanced->new(...);
+
+    my $inquiry = $payments->inquiry_transaction(
+        { ORIGID => 'FOO123', TENDER => 'C', }
+    );
+    say $response->message;
+
 =head3 void_transaction( $ORIGID )
 
 Voids a previous transaction.  Requires the ID of the transaction to void.
@@ -768,7 +771,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
